@@ -38,5 +38,10 @@ class ScanningLoader(TestLoader):
 
 
 if __name__ == '__main__':
-    main(module=None, testLoader=ScanningLoader())
+    if len(sys.argv) == 1:
+        testname = 'parsedatetime'
+    else:
+        testname = None
+
+    main(module=testname, testLoader=ScanningLoader())
 
